@@ -1,15 +1,16 @@
-__all__ = ["Config", "SmartPortConfig", "RegisterAccess", "SIGENERGY_MODBUS_PROTOCOL"]
+__all__ = ["Config", "SmartPortConfig", "RegisterAccess", "SIGENERGY_MODBUS_PROTOCOL", "SIGENERGY_MODBUS_PROTOCOL_PUBLISHED"]
 
 
 from . import const
 from .config import Config
 from .device_config import RegisterAccess, SmartPortConfig
-from .version import SIGENERGY_MODBUS_PROTOCOL
+from .version import SIGENERGY_MODBUS_PROTOCOL, SIGENERGY_MODBUS_PROTOCOL_PUBLISHED
 from pathlib import Path
 import argparse
 import logging
 import os
 import sys
+import time
 
 if os.isatty(sys.stdout.fileno()):
     logging.basicConfig(format="%(asctime)s %(levelname)-5s sigenergy2mqtt:%(module)s:%(lineno)s %(message)s", level=logging.INFO)
@@ -91,6 +92,12 @@ _parser.add_argument(
     default=os.getenv(const.SIGENERGY2MQTT_HASS_UNIQUE_ID_PREFIX, None),
     help="The prefix to use for Home Assistant unique IDs. Example: A prefix of 'prefix' will prepend 'prefix_' to unique IDs (default: sigen). Once you have set this, you should NEVER change it, as it will break existing entities in Home Assistant.",
 )
+_parser.add_argument(
+    "--hass-use-simplified-topics",
+    action="store_true",
+    dest=const.SIGENERGY2MQTT_HASS_USE_SIMPLIFIED_TOPICS,
+    help="Enable the simplified topic structure (sigenergy2mqtt/object_id/state) instead of the full Home Assistant topic structure (homeassistant/platform/device_id/object_id/state)",
+)
 _parser.add_argument(
     "--hass-device-name-prefix",
     nargs="?",
@@ -180,8 +187,16 @@ _parser.add_argument(
     action="store",
     dest=const.SIGENERGY2MQTT_MODBUS_INVERTER_SLAVE,
     type=int,
-    default=os.getenv(const.SIGENERGY2MQTT_MODBUS_INVERTER_SLAVE, None),
-    help="The Sigenergy Inverter Modbus Device ID (Slave ID). May be specified multiple times.",
+    help="** DEPRECATED ** Use --modbus-inverter-device-id instead.",
+)
+_parser.add_argument(
+    "--modbus-inverter-device-id",
+    nargs="*",
+    action="store",
+    dest=const.SIGENERGY2MQTT_MODBUS_INVERTER_DEVICE_ID,
+    type=int,
+    default=os.getenv(const.SIGENERGY2MQTT_MODBUS_INVERTER_DEVICE_ID, None),
+    help="**The Sigenergy Inverter Modbus Device ID. May be specified multiple times.",
 )
 _parser.add_argument(
     "--modbus-accharger-slave",
@@ -189,8 +204,16 @@ _parser.add_argument(
     action="store",
     dest=const.SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE,
     type=int,
-    default=os.getenv(const.SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE, None),
-    help="The Sigenergy AC Charger Modbus Device ID (Slave ID).",
+    help="** DEPRECATED ** Use --modbus-accharger-device-id instead.",
+)
+_parser.add_argument(
+    "--modbus-accharger-device-id",
+    nargs="*",
+    action="store",
+    dest=const.SIGENERGY2MQTT_MODBUS_ACCHARGER_DEVICE_ID,
+    type=int,
+    default=os.getenv(const.SIGENERGY2MQTT_MODBUS_ACCHARGER_DEVICE_ID, None),
+    help="The Sigenergy AC Charger Modbus Device ID.",
 )
 _parser.add_argument(
     "--modbus-dccharger-slave",
@@ -198,8 +221,16 @@ _parser.add_argument(
     action="store",
     dest=const.SIGENERGY2MQTT_MODBUS_DCCHARGER_SLAVE,
     type=int,
-    default=os.getenv(const.SIGENERGY2MQTT_MODBUS_DCCHARGER_SLAVE, None),
-    help="The Sigenergy DC Charger Modbus Device ID (Slave ID).",
+    help="** DEPRECATED ** Use --modbus-dccharger-device-id instead.",
+)
+_parser.add_argument(
+    "--modbus-dccharger-device-id",
+    nargs="*",
+    action="store",
+    dest=const.SIGENERGY2MQTT_MODBUS_DCCHARGER_DEVICE_ID,
+    type=int,
+    default=os.getenv(const.SIGENERGY2MQTT_MODBUS_DCCHARGER_DEVICE_ID, None),
+    help="The Sigenergy DC Charger Modbus Device ID.",
 )
 _parser.add_argument(
     "--modbus-readonly",
@@ -355,7 +386,15 @@ _parser.add_argument(
     dest=const.SIGENERGY2MQTT_PVOUTPUT_INTERVAL,
     type=int,
     default=os.getenv(const.SIGENERGY2MQTT_PVOUTPUT_INTERVAL, None),
-    help="The interval in minutes to send data to PVOutput (default: 5). Valid values are 5, 10 or 15 minutes.",
+    help="** DEPRECATED ** The Status Interval is now determined from the settings on pvoutput.org.",
+)
+_parser.add_argument(
+    "--pvoutput-temp-topic",
+    nargs="?",
+    action="store",
+    dest=const.SIGENERGY2MQTT_PVOUTPUT_TEMP_TOPIC,
+    default=os.getenv(const.SIGENERGY2MQTT_PVOUTPUT_TEMP_TOPIC, None),
+    help="An MQTT topic from which the current temperature can be read. This is used to send the temperature to PVOutput. If not specified, the temperature will not be sent to PVOutput.",
 )
 _parser.add_argument(
     "--pvoutput-log-level",
@@ -365,6 +404,12 @@ _parser.add_argument(
     default=os.getenv(const.SIGENERGY2MQTT_PVOUTPUT_LOG_LEVEL, None),
     help="Set the PVOutput log level. Valid values are: DEBUG, INFO, WARNING, ERROR or CRITICAL. Default is WARNING (warnings, errors and critical failures)",
 )
+_parser.add_argument(
+    "--no-metrics",
+    action="store_true",
+    dest=const.SIGENERGY2MQTT_NO_METRICS,
+    help="Do not publish any sigenergy2mqtt metrics.",
+)
 _parser.add_argument(
     "--clean",
     action="store_true",
@@ -388,8 +433,9 @@ if _args.show_version:
 def apply_cli_to_env(variable: str, value: str) -> None:
     was = os.getenv(variable)
     if value is not None:
-        os.environ[variable] = str(value)
-        _logger.debug(f"Environment variable '{variable}' overridden from command line: set to '{value}' (was '{was}')")
+        if value != was:
+            os.environ[variable] = str(value)
+            _logger.debug(f"Environment variable '{variable}' overridden from command line: set to '{value}' (was '{was}')")
     else:
         if was is not None:
             os.environ[variable] = ""
@@ -399,7 +445,16 @@ def apply_cli_to_env(variable: str, value: str) -> None:
 
 
 if _args.SIGENERGY2MQTT_LOG_LEVEL:
+    Config.log_level = getattr(logging, _args.SIGENERGY2MQTT_LOG_LEVEL)
     _logger.setLevel(getattr(logging, _args.SIGENERGY2MQTT_LOG_LEVEL))
+    _logger.log(_logger.level, f"sigenergy2mqtt log-level changed to {logging.getLevelName(Config.log_level)}")
+
+for key in os.environ.keys():
+    if key.startswith("SIGENERGY2MQTT_"):
+        if key.endswith("_SLAVE"):
+            _logger.warning(f"The environment variable '{key}' is deprecated and will be removed in a future version. Use '{key.replace('_SLAVE', '_DEVICE_ID')}' instead.")
+        elif key == const.SIGENERGY2MQTT_PVOUTPUT_INTERVAL:
+            _logger.warning(f"The environment variable '{key}' is deprecated and will be removed in a future version. The Status Interval is now determined from the settings on pvoutput.org.")
 
 for arg in vars(_args):
     if arg == "clean":
@@ -408,10 +463,12 @@ for arg in vars(_args):
     elif (
         arg == const.SIGENERGY2MQTT_HASS_ENABLED
         or arg == const.SIGENERGY2MQTT_HASS_DISCOVERY_ONLY
+        or arg == const.SIGENERGY2MQTT_HASS_USE_SIMPLIFIED_TOPICS
         or arg == const.SIGENERGY2MQTT_MODBUS_NO_REMOTE_EMS
         or arg == const.SIGENERGY2MQTT_MQTT_ANONYMOUS
         or arg == const.SIGENERGY2MQTT_PVOUTPUT_ENABLED
         or arg == const.SIGENERGY2MQTT_SMARTPORT_ENABLED
+        or arg == const.SIGENERGY2MQTT_NO_METRICS
     ) and getattr(_args, arg) not in ["true", "True", True, 1]:  # argparse will store false by default, so ignore unless actually specified (and therefore true)
         continue
     elif arg == const.SIGENERGY2MQTT_MODBUS_READ_ONLY and getattr(_args, arg) in ["true", "True", True, 1]:
@@ -419,6 +476,12 @@ for arg in vars(_args):
         apply_cli_to_env(const.SIGENERGY2MQTT_MODBUS_READ_WRITE, "false")
         apply_cli_to_env(const.SIGENERGY2MQTT_MODBUS_WRITE_ONLY, "false")
         continue
+    elif arg == const.SIGENERGY2MQTT_MODBUS_INVERTER_SLAVE and getattr(_args, arg) is not None:
+        _logger.warning("** DEPRECATED ** The '--modbus-inverter-slave' option is deprecated and will be removed in a future version. Use '--modbus-inverter-device-id' instead.")
+    elif arg == const.SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE and getattr(_args, arg) is not None:
+        _logger.warning("** DEPRECATED ** The '--modbus-accharger-slave' option is deprecated and will be removed in a future version. Use '--modbus-accharger-device-id' instead.")
+    elif arg == const.SIGENERGY2MQTT_MODBUS_DCCHARGER_SLAVE and getattr(_args, arg) is not None:
+        _logger.warning("** DEPRECATED ** The '--modbus-dccharger-slave' option is deprecated and will be removed in a future version. Use '--modbus-dccharger-device-id' instead.")
     override = getattr(_args, arg)
     if override:
         if isinstance(override, list):
@@ -451,8 +514,13 @@ for _storage_base_path in ["/data/", "/var/lib/", str(Path.home()), "/tmp/"]:
             path.mkdir()
         logging.debug(f"{Config.persistent_state_path=}")
         break
-    else:
-        logging.debug(f"Unable to create persistent state path in {_storage_base_path}: Not writable or does not exist")
 if Config.persistent_state_path == ".":
     _logger.critical("Unable to create persistent state path!")
     sys.exit(1)
+
+directory = Path(Config.persistent_state_path)
+threshold_time = time.time() - (7 * 86400)
+for file in directory.iterdir():
+    if file.is_file() and not file.name.endswith(".publishable") and not file.name.endswith(".token") and file.stat().st_mtime < threshold_time:
+        _logger.debug(f"Removing stale state file: {file}")
+        file.unlink()
