@@ -25,6 +25,7 @@ class Config:
     sensor_overrides: dict = {}
 
     sanity_check_default_kw: float = 100.0
+    metrics_enabled: bool = True
 
     persistent_state_path: str = "."
 
@@ -71,7 +72,9 @@ class Config:
                             overrides["sensor-overrides"][check_string(os.environ[key], key, allow_empty=False, allow_none=False)] = {"debug-logging": True}
                             overrides["log-level"] = logging.DEBUG
                         case const.SIGENERGY2MQTT_SANITY_CHECK_DEFAULT_KW:
-                            overrides["sanity-check-default-kw"] = check_float(os.environ[key], key, allow_none=False, min=0) 
+                            overrides["sanity-check-default-kw"] = check_float(os.environ[key], key, allow_none=False, min=0)
+                        case const.SIGENERGY2MQTT_NO_METRICS:
+                            overrides["no-metrics"] = check_bool(os.environ[key], key)
                         case const.SIGENERGY2MQTT_HASS_ENABLED:
                             overrides["home-assistant"]["enabled"] = check_bool(os.environ[key], key)
                         case const.SIGENERGY2MQTT_HASS_ENTITY_ID_PREFIX:
@@ -84,18 +87,20 @@ class Config:
                             overrides["home-assistant"]["discovery-prefix"] = check_string(os.environ[key], key)
                         case const.SIGENERGY2MQTT_HASS_UNIQUE_ID_PREFIX:
                             overrides["home-assistant"]["unique-id-prefix"] = check_string(os.environ[key], key)
+                        case const.SIGENERGY2MQTT_HASS_USE_SIMPLIFIED_TOPICS:
+                            overrides["home-assistant"]["use-simplified-topics"] = check_bool(os.environ[key], key)
                         case const.SIGENERGY2MQTT_MODBUS_HOST:
                             overrides["modbus"][0]["host"] = check_host(os.environ[key], key)
                         case const.SIGENERGY2MQTT_MODBUS_PORT:
                             overrides["modbus"][0]["port"] = check_port(os.environ[key], key)
                         case const.SIGENERGY2MQTT_MODBUS_LOG_LEVEL:
                             overrides["modbus"][0]["log-level"] = check_log_level(os.environ[key], key)
-                        case const.SIGENERGY2MQTT_MODBUS_INVERTER_SLAVE:
-                            overrides["modbus"][0]["inverters"] = check_int_list([int(slave) for slave in os.environ[key].split(",")], key)
-                        case const.SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE:
-                            overrides["modbus"][0]["ac-chargers"] = check_int_list([int(slave) for slave in os.environ[key].split(",")], key)
-                        case const.SIGENERGY2MQTT_MODBUS_DCCHARGER_SLAVE:
-                            overrides["modbus"][0]["dc-chargers"] = check_int_list([int(slave) for slave in os.environ[key].split(",")], key)
+                        case const.SIGENERGY2MQTT_MODBUS_INVERTER_SLAVE | const.SIGENERGY2MQTT_MODBUS_INVERTER_DEVICE_ID:
+                            overrides["modbus"][0]["inverters"] = check_int_list([int(device_id) for device_id in os.environ[key].split(",")], key)
+                        case const.SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE | const.SIGENERGY2MQTT_MODBUS_ACCHARGER_DEVICE_ID:
+                            overrides["modbus"][0]["ac-chargers"] = check_int_list([int(device_id) for device_id in os.environ[key].split(",")], key)
+                        case const.SIGENERGY2MQTT_MODBUS_DCCHARGER_SLAVE | const.SIGENERGY2MQTT_MODBUS_DCCHARGER_DEVICE_ID:
+                            overrides["modbus"][0]["dc-chargers"] = check_int_list([int(device_id) for device_id in os.environ[key].split(",")], key)
                         case const.SIGENERGY2MQTT_MODBUS_NO_REMOTE_EMS:
                             overrides["modbus"][0]["no-remote-ems"] = check_bool(os.environ[key], key)
                         case const.SIGENERGY2MQTT_MODBUS_READ_ONLY:
@@ -151,7 +156,9 @@ class Config:
                         case const.SIGENERGY2MQTT_PVOUTPUT_CONSUMPTION:
                             overrides["pvoutput"]["consumption"] = check_bool(os.environ[key], key)
                         case const.SIGENERGY2MQTT_PVOUTPUT_INTERVAL:
-                            overrides["pvoutput"]["interval-minutes"] = check_int(os.environ[key], key, min=5, max=15)
+                            pass  # Deprecated
+                        case const.SIGENERGY2MQTT_PVOUTPUT_TEMP_TOPIC:
+                            overrides["pvoutput"]["temperature-topic"] = check_string(os.environ[key], key, allow_none=False, allow_empty=False)
                         case const.SIGENERGY2MQTT_PVOUTPUT_TESTING:
                             overrides["pvoutput"]["testing"] = check_bool(os.environ[key], key)
                         case _:
@@ -176,6 +183,9 @@ class Config:
                 case "sanity-check-default-kw":
                     logging.debug(f"Applying {'override from env/cli' if override else 'configuration'}: sanity-check-default-kw = {data[name]}")
                     Config.sanity_check_default_kw = check_float(data[name], name, allow_none=False, min=0)
+                case "no-metrics":
+                    logging.debug(f"Applying {'override from env/cli' if override else 'configuration'}: no-metrics = {data[name]}")
+                    Config.metrics_enabled = not check_bool(data[name], name)
                 case "mqtt":
                     Config.mqtt.configure(data[name], override)
                 case "modbus":
