@@ -1,4 +1,5 @@
 from .types import DeviceType
+from pathlib import Path
 from pymodbus import ModbusException
 from pymodbus.client import AsyncModbusTcpClient as ModbusClient
 from random import randint, uniform
@@ -161,6 +162,19 @@ class Device(Dict[str, any], metaclass=abc.ABCMeta):
             self._write_sensors[sensor.unique_id] = sensor
             self._add_to_all_sensors(sensor)
 
+    def get_all_sensors(self, search_children: bool = True) -> Dict[str, Sensor]:
+        """
+        Returns all sensors in this device and its children.
+        If search_children is False, only returns sensors in this device.
+        """
+        if search_children:
+            all_sensors = self._all_sensors.copy()
+            for child in self._children:
+                all_sensors.update(child.get_all_sensors(search_children=True))
+            return all_sensors
+        else:
+            return self._all_sensors
+
     def get_sensor(self, unique_id: str, search_children: bool = False) -> Sensor:
         if unique_id in self._all_sensors:
             return self._all_sensors[unique_id]
@@ -191,7 +205,7 @@ class Device(Dict[str, any], metaclass=abc.ABCMeta):
         topic = f"{Config.home_assistant.discovery_prefix}/device/{self.unique_id}/config"
         components = {}
         for sensor in self.sensors.values():
-            components.update(sensor.get_discovery())
+            components.update(sensor.get_discovery(mqtt))
         if len(components) > 0:
             discovery = {}
             discovery["dev"] = self
@@ -202,7 +216,11 @@ class Device(Dict[str, any], metaclass=abc.ABCMeta):
                 logging.debug(f"{self.name} - Publishing empty discovery ({clean=})")
                 mqtt.publish(topic, None, qos=1, retain=True)  # Clear retained messages
             logging.info(f"{self.name} - Publishing discovery")
-            logging.debug(f"{self.name} - Discovery JSON:\n{discovery_json}")
+            if logging.getLogger().isEnabledFor(logging.DEBUG):
+                discovery_dump = Path(Config.persistent_state_path, f"{self.unique_id}.discovery.json")
+                with discovery_dump.open("w") as f:
+                    f.write(discovery_json)
+                logging.debug(f"{self.name} - Discovery JSON dumped to {discovery_dump.resolve()}")
             info = mqtt.publish(topic, discovery_json, qos=2, retain=True)
         else:
             logging.debug(f"{self.name} - Publishing empty availability (No components found)")
@@ -233,54 +251,62 @@ class Device(Dict[str, any], metaclass=abc.ABCMeta):
                 for sensor in publishable:
                     if isinstance(sensor, ReadOnlySensor) and interval != sensor.scan_interval:
                         logging.warning(f"Sensor {sensor.__class__.__name__} scan-interval ({sensor.scan_interval}s) ignored - the interval of {self.name} Sensor Group [{names}] is {interval}s")
-                wait: float = uniform(0.5, min(5, interval))
-                if debug_logging:
-                    logging.debug(f"{self.name} Sensor Scan Group [{names}] initial wait is {wait} seconds")
+                last_publish: float = time.monotonic()
+                next_publish: float = last_publish + uniform(0.5, min(5, interval))
                 actual_elapsed: list[float] = []
                 if debug_logging:
-                    logging.debug(f"{self.name} Sensor Scan Group [{names}] commenced (Interval = {interval} seconds)")
+                    logging.debug(f"{self.name} Sensor Scan Group [{names}] commenced ({interval=}s)")
                 while self.online:
-                    started = time.time()  # Grab the started time first, so that elapsed contains ALL activity
+                    now = time.monotonic()  # Grab the started time first, so that elapsed contains ALL activity
                     for sensor in publishable:
                         if sensor.force_publish:
                             if debug_logging:
-                                logging.debug(f"{self.name} Sensor Scan Group [{names}] wait interrupted at {wait:.2f}s because force_publish set on {sensor.__class__.__name__}")
-                            wait = 0  # If any sensor requires a force publish, process all of them now
+                                logging.debug(
+                                    f"{self.name} Sensor Scan Group [{names}] wait interrupted with {next_publish - now:.2f}s remaining because force_publish set on {sensor.__class__.__name__}"
+                                )
+                            next_publish = now  # If any sensor requires a force publish, process all of them now
                             break
-                    if wait <= 0:
+                    if next_publish <= now:
+                        if debug_logging:
+                            logging.debug(f"{self.name} Sensor Scan Group [{names}] publishing sensors (elapsed={now - last_publish:.2f}s)")
+                        last_publish = now
                         try:
                             for sensor in sensors:
                                 if isinstance(sensor, ReadableSensorMixin) and sensor.publishable:  # ReadOnlySensor and subclasses (e.g. ReadWriteSensor, etc.)
                                     await sensor.publish(mqtt, modbus)
-                                    actual_elapsed.append(sensor.latest_interval)
-                                    if len(actual_elapsed) > 100:
-                                        actual_elapsed = actual_elapsed[-100:]
+                                    if sensor.latest_interval is not None:
+                                        actual_elapsed.append(sensor.latest_interval)
+                                        if len(actual_elapsed) > 100:
+                                            actual_elapsed = actual_elapsed[-100:]
                             if self.rediscover:
-                                lock = ModbusLockFactory.get_lock(modbus)
-                                logging.info(f"{self.name} Sensor Scan Group [{names}]: Acquiring lock to republish discovery... ({lock.waiters=})")
-                                async with lock.acquire_with_timeout(timeout=1):
+                                lock = ModbusLockFactory.get(modbus)
+                                logging.debug(f"{self.name} Sensor Scan Group [{names}]: Acquiring lock to republish discovery... ({lock.waiters=})")
+                                async with lock.lock(timeout=1):
                                     self.rediscover = False
                                     self.publish_discovery(mqtt, clean=False)
-                            average_excess = max(0.0, statistics.fmean(actual_elapsed) - interval)
-                            elapsed = time.time() - started
+                            average_excess = statistics.fmean(actual_elapsed) - interval if len(actual_elapsed) > 0 else 0
+                            elapsed = time.monotonic() - now
                             if elapsed > interval and modbus.connected:
-                                logging.warning(f"{self.name} Sensor Scan Group [{names}] exceeded scan interval ({interval}s) Elapsed = {elapsed:.2f}s Average Excess Time = {average_excess:.2f}s")
-                            wait = max(interval - elapsed, 0.5)
+                                logging.info(f"{self.name} Sensor Scan Group [{names}] exceeded scan interval ({interval=}s) {elapsed=:.2f}s {average_excess=:.3f}s")
+                            next_publish = time.monotonic() + max(interval - elapsed, 0.5)
+                            if debug_logging:
+                                logging.debug(f"{self.name} Sensor Scan Group [{names}] {interval=}s {elapsed=:.2f}s next={next_publish - time.monotonic():.2f}s {average_excess=:.3f}s")
                         except ModbusException as e:
-                            lock = ModbusLockFactory.get_lock(modbus)
-                            logging.info(f"{self.name} Sensor Scan Group [{names}] handling {e!s}: Acquiring lock before attempting to reconnect... ({lock.waiters=})")
-                            async with lock.acquire_with_timeout(timeout=None):
+                            lock = ModbusLockFactory.get(modbus)
+                            logging.debug(f"{self.name} Sensor Scan Group [{names}] handling {e!s}: Acquiring lock before attempting to reconnect... ({lock.waiters=})")
+                            async with lock.lock(timeout=None):
                                 if not modbus.connected and self.online:
-                                    logging.info(f"{self.name} Sensor Scan Group [{names}] attempting to reconnect to Modbus...")
+                                    logging.info(f"{self.name} attempting to reconnect to Modbus...")
                                     while not modbus.connected:
                                         modbus.close()
                                         await asyncio.sleep(0.5)
                                         await modbus.connect()
                                         await asyncio.sleep(1)
-                                    logging.info(f"{self.name} Sensor Scan Group [{names}] reconnected to Modbus")
-                    sleep = min(wait, 1)  # Only sleep for a maximum of 1 second so that changes to self.online are handled more quickly
-                    wait -= sleep
-                    if wait > 0:
+                                    logging.info(f"{self.name} reconnected to Modbus")
+                        except Exception as e:
+                            logging.error(f"{self.name} Sensor Scan Group [{names}] encountered an error: {repr(e)}")
+                    sleep = min(next_publish - time.monotonic(), 1)  # Only sleep for a maximum of 1 second so that changes to self.online are handled more quickly
+                    if sleep > 0:
                         task = asyncio.create_task(asyncio.sleep(sleep))
                         for sensor in sensors:
                             sensor.sleeper_task = task
@@ -326,23 +352,24 @@ class Device(Dict[str, any], metaclass=abc.ABCMeta):
         return tasks
 
     def subscribe(self, mqtt: MqttClient, mqtt_handler: MqttHandler) -> None:
-        mqtt_handler.register(mqtt, f"{Config.home_assistant.discovery_prefix}/status", self.on_ha_state_change)
+        result = mqtt_handler.register(mqtt, f"{Config.home_assistant.discovery_prefix}/status", self.on_ha_state_change)
+        logging.debug(f"{self.name} subscribed to topic {Config.home_assistant.discovery_prefix}/status for Home Assistant state changes ({result=})")
         for sensor in self.sensors.values():
             if isinstance(sensor, WritableSensorMixin):
                 try:
-                    mqtt_handler.register(mqtt, sensor.command_topic, sensor.set_value)
+                    result = mqtt_handler.register(mqtt, sensor.command_topic, sensor.set_value)
                     if sensor.debug_logging:
-                        logging.debug(f"Sensor {sensor.name} subscribed to topic {sensor.command_topic} for writing")
+                        logging.debug(f"Sensor {sensor.name} subscribed to topic {sensor.command_topic} for writing ({result=})")
                 except Exception as e:
-                    logging.error(f"Sensor {sensor.name} failed to subscribe to topic {sensor.command_topic}: {e}")
+                    logging.error(f"Sensor {sensor.name} failed to subscribe to topic {sensor.command_topic}: {repr(e)}")
             if isinstance(sensor, ObservableMixin):
                 for topic in sensor.observable_topics():
                     try:
-                        mqtt_handler.register(mqtt, topic, sensor.notify)
+                        result = mqtt_handler.register(mqtt, topic, sensor.notify)
                         if sensor.debug_logging:
-                            logging.debug(f"Sensor {sensor.name} subscribed to topic {topic} for notification")
+                            logging.debug(f"Sensor {sensor.name} subscribed to topic {topic} for notification ({result=})")
                     except Exception as e:
-                        logging.error(f"Sensor {sensor.name} failed to subscribe to topic {topic}: {e}")
+                        logging.error(f"Sensor {sensor.name} failed to subscribe to topic {topic}: {repr(e)}")
         for device in self._children:
             device.subscribe(mqtt, mqtt_handler)
 
