@@ -103,9 +103,9 @@ class InverterFirmwareVersion(ReadOnlySensor, HybridInverter, PVInverter):
 
     async def get_state(self, raw: bool = False, republish: bool = False, **kwargs) -> float | int | str | None:
         value = await super().get_state(raw=raw, republish=republish, **kwargs)
-        if "device" in self and value is not None:
+        if "device" in self and value is not None and self.device["hw"] != value:
             # Firmware has been updated, so need to update the device and to republish discovery
-            self.device["hw_version"] = value
+            self.device["hw"] = value
             self.device.rediscover = True
         return value
 
@@ -374,6 +374,7 @@ class DailyChargeEnergy(ReadOnlySensor, HybridInverter):
             precision=2,
         )
         self["enabled_by_default"] = True
+        self._sanity.min_value = None
 
 
 class AccumulatedChargeEnergy(ReadOnlySensor, HybridInverter):
@@ -418,6 +419,10 @@ class DailyDischargeEnergy(ReadOnlySensor, HybridInverter):
             precision=2,
         )
         self["enabled_by_default"] = True
+        self._sanity.min_value = None
+
+    def set_state(self, state: float | int | str) -> None:
+        super().set_state(state)
 
 
 class AccumulatedDischargeEnergy(ReadOnlySensor, HybridInverter):
@@ -863,7 +868,6 @@ class InverterActivePowerFixedValueAdjustmentFeedback(ReadOnlySensor, HybridInve
             gain=1000,
             precision=2,
         )
-        self._publishable = False  # Returns 0x02 ILLEGAL DATA ADDRESS on F/W V100R001C00SPC109B09 (Hybrid Inverter)
 
 
 class InverterReactivePowerFixedValueAdjustmentFeedback(ReadOnlySensor, HybridInverter, PVInverter):
@@ -879,13 +883,12 @@ class InverterReactivePowerFixedValueAdjustmentFeedback(ReadOnlySensor, HybridIn
             data_type=ModbusClient.DATATYPE.INT32,
             scan_interval=Config.devices[plant_index].scan_interval.medium if plant_index < len(Config.devices) else 60,
             unit=UnitOfReactivePower.KILO_VOLT_AMPERE_REACTIVE,
-            device_class=DeviceClass.POWER,
-            state_class=StateClass.MEASUREMENT,
+            device_class=None,
+            state_class=None,
             icon="mdi:comment-quote",
             gain=1000,
             precision=2,
         )
-        self._publishable = False  # Returns 0x02 ILLEGAL DATA ADDRESS on F/W V100R001C00SPC109B09 (Hybrid Inverter)
 
 
 class InverterActivePowerPercentageAdjustmentFeedback(ReadOnlySensor, HybridInverter, PVInverter):
@@ -907,7 +910,6 @@ class InverterActivePowerPercentageAdjustmentFeedback(ReadOnlySensor, HybridInve
             gain=100,
             precision=None,
         )
-        self._publishable = False  # Returns 0x02 ILLEGAL DATA ADDRESS on F/W V100R001C00SPC109B09 (Hybrid Inverter)
 
 
 class InverterReactivePowerPercentageAdjustmentFeedback(ReadOnlySensor, HybridInverter, PVInverter):
@@ -929,7 +931,6 @@ class InverterReactivePowerPercentageAdjustmentFeedback(ReadOnlySensor, HybridIn
             gain=100,
             precision=None,
         )
-        self._publishable = False  # Returns 0x02 ILLEGAL DATA ADDRESS on F/W V100R001C00SPC109B09 (Hybrid Inverter)
 
 
 class InverterMaxBatteryTemperature(ReadOnlySensor, HybridInverter):
@@ -1710,6 +1711,7 @@ class InverterPVDailyGeneration(ReadOnlySensor, HybridInverter, PVInverter):
             unique_id_override=f"{Config.home_assistant.unique_id_prefix}_{plant_index}_inverter_{device_address}_daily_pv_energy",  # Originally was a ResettableAccumulationSensor prior to Modbus Protocol v2.7
         )
         self["enabled_by_default"] = True
+        self._sanity.min_value = None
 
     def get_discovery_components(self) -> Dict[str, dict[str, Any]]:
         components: Dict[str, dict[str, Any]] = super().get_discovery_components()
